@@ -5,7 +5,7 @@ use std::sync::{Arc, Mutex};
 use super::utils::{ensure_frame_size, WS_FRAME_SIZE};
 use super::{
     ws_client_internal::{MiscMessage, WSClientInternal},
-    Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
+    Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
 };
 use log::*;
 use serde_json::Value;
@@ -158,8 +158,17 @@ impl_candlestick!(BinanceWSClient);
 /// Define market specific client.
 macro_rules! define_market_client {
     ($struct_name:ident, $default_url:ident) => {
-        impl<'a> WSClient<'a> for $struct_name<'a> {
-            fn new(on_msg: Arc<Mutex<dyn FnMut(String) + 'a + Send>>, url: Option<&str>) -> Self {
+        impl<'a> $struct_name<'a> {
+            /// Creates a Binance websocket client.
+            ///
+            /// # Arguments
+            ///
+            /// * `on_msg` - A callback function to process websocket messages
+            /// * `url` - Optional server url, usually you don't need specify it
+            pub fn new(
+                on_msg: Arc<Mutex<dyn FnMut(String) + 'a + Send>>,
+                url: Option<&str>,
+            ) -> Self {
                 let real_url = match url {
                     Some(endpoint) => endpoint,
                     None => $default_url,
@@ -168,7 +177,9 @@ macro_rules! define_market_client {
                     client: BinanceWSClient::new(real_url, on_msg),
                 }
             }
+        }
 
+        impl<'a> WSClient<'a> for $struct_name<'a> {
             fn subscribe_trade(&self, channels: &[String]) {
                 <$struct_name as Trade>::subscribe_trade(self, channels);
             }
@@ -181,6 +192,10 @@ macro_rules! define_market_client {
                 <$struct_name as OrderBookTopK>::subscribe_orderbook_topk(self, channels);
             }
 
+            fn subscribe_l3_orderbook(&self, channels: &[String]) {
+                <$struct_name as Level3OrderBook>::subscribe_l3_orderbook(self, channels);
+            }
+
             fn subscribe_ticker(&self, channels: &[String]) {
                 <$struct_name as Ticker>::subscribe_ticker(self, channels);
             }
@@ -300,6 +315,10 @@ impl_candlestick!(BinanceSpotWSClient);
 impl_candlestick!(BinanceInverseWSClient);
 impl_candlestick!(BinanceLinearWSClient);
 
+panic_l3_orderbook!(BinanceSpotWSClient);
+panic_l3_orderbook!(BinanceInverseWSClient);
+panic_l3_orderbook!(BinanceLinearWSClient);
+
 #[cfg(test)]
 mod tests {
     #[test]
