@@ -5,7 +5,7 @@ use std::{collections::HashMap, time::Duration};
 use super::{
     utils::CHANNEL_PAIR_DELIMITER,
     ws_client_internal::{MiscMessage, WSClientInternal},
-    Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
+    Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
 };
 use log::*;
 use serde_json::Value;
@@ -134,6 +134,8 @@ fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
 
 impl_candlestick!(BitmexWSClient);
 
+panic_l3_orderbook!(BitmexWSClient);
+
 define_client!(
     BitmexWSClient,
     EXCHANGE_NAME,
