@@ -4,7 +4,7 @@ use std::sync::{Arc, Mutex};
 
 use super::utils::ensure_frame_size;
 use super::ws_client_internal::{MiscMessage, WSClientInternal};
-use super::{Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
+use super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
 
 use log::*;
 use serde_json::Value;
@@ -135,6 +135,8 @@ fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
 
 impl_candlestick!(DeribitWSClient);
 
+panic_l3_orderbook!(DeribitWSClient);
+
 define_client!(
     DeribitWSClient,
     EXCHANGE_NAME,
