@@ -6,7 +6,7 @@ use super::{
     utils::CHANNEL_PAIR_DELIMITER,
     ws_client_internal::{MiscMessage, WSClientInternal},
 };
-use super::{Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
+use super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
 
 use log::*;
 use serde_json::Value;
@@ -105,6 +105,8 @@ impl<'a> Candlestick for FtxWSClient<'a> {
     }
 }
 
+panic_l3_orderbook!(FtxWSClient);
+
 define_client!(
     FtxWSClient,
     EXCHANGE_NAME,
