@@ -2,7 +2,7 @@ use crate::WSClient;
 use std::sync::{Arc, Mutex};
 
 use super::super::ws_client_internal::WSClientInternal;
-use super::super::{Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
+use super::super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
 use super::utils::{
     channels_to_commands, on_misc_msg, to_candlestick_raw_channel_shared, to_raw_channel,
     EXCHANGE_NAME,
@@ -38,6 +38,8 @@ fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
 
 impl_candlestick!(GateSpotWSClient);
 
+panic_l3_orderbook!(GateSpotWSClient);
+
 define_client!(
     GateSpotWSClient,
     EXCHANGE_NAME,
