@@ -7,7 +7,7 @@ use serde_json::Value;
 use tungstenite::Message;
 
 use super::ws_client_internal::{MiscMessage, WSClientInternal};
-use super::{Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
+use super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
 
 pub(super) const EXCHANGE_NAME: &str = "huobi";
 
@@ -230,8 +230,17 @@ impl_candlestick!(HuobiWSClient);
 /// Define market specific client.
 macro_rules! define_market_client {
     ($struct_name:ident, $default_url:ident) => {
-        impl<'a> WSClient<'a> for $struct_name<'a> {
-            fn new(on_msg: Arc<Mutex<dyn FnMut(String) + 'a + Send>>, url: Option<&str>) -> Self {
+        impl<'a> $struct_name<'a> {
+            /// Creates a Huobi websocket client.
+            ///
+            /// # Arguments
+            ///
+            /// * `on_msg` - A callback function to process websocket messages
+            /// * `url` - Optional server url, usually you don't need specify it
+            pub fn new(
+                on_msg: Arc<Mutex<dyn FnMut(String) + 'a + Send>>,
+                url: Option<&str>,
+            ) -> Self {
                 let real_url = match url {
                     Some(endpoint) => endpoint,
                     None => $default_url,
@@ -240,7 +249,9 @@ macro_rules! define_market_client {
                     client: HuobiWSClient::new(real_url, on_msg),
                 }
             }
+        }
 
+        impl<'a> WSClient<'a> for $struct_name<'a> {
             fn subscribe_trade(&self, channels: &[String]) {
                 <$struct_name as Trade>::subscribe_trade(self, channels);
             }
@@ -253,6 +264,10 @@ macro_rules! define_market_client {
                 <$struct_name as OrderBookTopK>::subscribe_orderbook_topk(self, channels);
             }
 
+            fn subscribe_l3_orderbook(&self, channels: &[String]) {
+                <$struct_name as Level3OrderBook>::subscribe_l3_orderbook(self, channels);
+            }
+
             fn subscribe_ticker(&self, channels: &[String]) {
                 <$struct_name as Ticker>::subscribe_ticker(self, channels);
             }
@@ -393,6 +408,12 @@ impl_orderbook_snapshot!(HuobiInverseSwapWSClient);
 impl_orderbook_snapshot!(HuobiLinearSwapWSClient);
 impl_orderbook_snapshot!(HuobiOptionWSClient);
 
+panic_l3_orderbook!(HuobiSpotWSClient);
+panic_l3_orderbook!(HuobiFutureWSClient);
+panic_l3_orderbook!(HuobiInverseSwapWSClient);
+panic_l3_orderbook!(HuobiLinearSwapWSClient);
+panic_l3_orderbook!(HuobiOptionWSClient);
+
 #[cfg(test)]
 mod tests {
     #[test]
