@@ -61,8 +61,6 @@
 
 mod clients;
 
-use std::sync::{Arc, Mutex};
-
 pub use clients::binance::*;
 pub use clients::binance_option::*;
 // pub use clients::bitfinex::*;
@@ -86,14 +84,6 @@ pub use clients::zbg::*;
 
 /// The public interface of every WebSocket client.
 pub trait WSClient<'a> {
-    /// Creates a new client.
-    ///
-    /// # Arguments
-    ///
-    /// * `on_msg` - A callback function to process original JSON messages
-    /// * `url` - Optional server url, usually you don't need specify it
-    fn new(on_msg: Arc<Mutex<dyn FnMut(String) + 'a + Send>>, url: Option<&str>) -> Self;
-
     /// Subscribes to trade channels.
     ///
     /// A trade channel sends tick-by-tick trade data,  which is the complete
@@ -157,6 +147,14 @@ pub trait WSClient<'a> {
     /// * OKEx `depth5`, top 5, every 100ms
     fn subscribe_orderbook_topk(&self, pairs: &[String]);
 
+    /// Subscribes to level3 orderebook channels.
+    ///
+    /// **Only bitfinex, bitstamp, coinbase_pro and kucoin have level3 orderbook channels.**
+    ///
+    /// The level3 orderbook is the orginal orderbook of an exchange, it is
+    /// non-aggregated by price level and updated tick-by-tick.
+    fn subscribe_l3_orderbook(&self, symbols: &[String]);
+
     /// Subscribes to ticker channels.
     ///
     /// A ticker channel pushes realtime 24hr rolling window ticker messages,
@@ -207,12 +205,3 @@ pub trait WSClient<'a> {
     /// Breaks the loop and closes the connection.
     fn close(&self);
 }
-
-/// Level3 orderbook data.
-pub trait Level3OrderBook {
-    /// Subscribes to level3 orderebook channels.
-    ///
-    /// The level3 orderbook is the orginal orderbook of an exchange, it is
-    /// non-aggregated by price level and updated tick-by-tick.
-    fn subscribe_l3_orderbook(&self, symbols: &[String]);
-}
