@@ -3,7 +3,7 @@ mod utils;
 
 #[cfg(test)]
 mod bitfinex_spot {
-    use crypto_ws_client::{BitfinexWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{BitfinexWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
@@ -79,7 +79,7 @@ mod bitfinex_spot {
 
 #[cfg(test)]
 mod bitfinex_swap {
-    use crypto_ws_client::{BitfinexWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{BitfinexWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
