@@ -3,7 +3,7 @@ mod utils;
 
 #[cfg(test)]
 mod kucoin_spot {
-    use crypto_ws_client::{KuCoinSpotWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{KuCoinSpotWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
@@ -99,7 +99,7 @@ mod kucoin_spot {
 
 #[cfg(test)]
 mod kucoin_inverse_swap {
-    use crypto_ws_client::{KuCoinSwapWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
@@ -193,7 +193,7 @@ mod kucoin_inverse_swap {
 
 #[cfg(test)]
 mod kucoin_linear_swap {
-    use crypto_ws_client::{KuCoinSwapWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
@@ -287,7 +287,7 @@ mod kucoin_linear_swap {
 
 #[cfg(test)]
 mod kucoin_inverse_future {
-    use crypto_ws_client::{KuCoinSwapWSClient, Level3OrderBook, WSClient};
+    use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::{Arc, Mutex};
 
     #[test]
